package de.intevation.gnv.state.describedata;

/**
 * This is the default implementation of <code>SingleValueDescribeData</code>.
 * This object is used to store a single value for a specific name.
 *
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 */
public class DefaultSingleValueDescribeData implements SingleValueDescribeData {

    private static final long serialVersionUID = 3580176842483316917L;

    private String name = null;

    private String value = null;

    private String state = null;

    /**
     * Constructor to create new objects without a specific state.
     *
     * @param name The name of this object.
     * @param value The value of this object.
     */
    public DefaultSingleValueDescribeData(String name, String value) {
        this(name, value, null);
    }

    /**
     * Constructor to create new objects with a specific state.
     *
     * @param name The name of this object.
     * @param value The value of this object.
     * @param state The state this object belongs to.
     */
    public DefaultSingleValueDescribeData(
        String name,
        String value,
        String state
    ) {
        super();
        this.name = name;
        this.value = value;
        this.state = state;
    }

    public String getName() {
        return this.name;
    }

    public String getValue() {
        return this.value;
    }

    public void setValue(String value) {
        this.value = value;
    }

    public String getState() {
        return this.state;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :